@@ -547,14 +547,14 @@ class DataWarehouse:
 
     def get_participant_by_id(self, study, participant):
         """
-         maps from unique participant.id to the local; id stored with measurements in the warehouse
+         maps from unique participant.id to the local id stored with measurements in the warehouse
          :param study: the study id
          :param participant: the id of the participant in the study
          :return The participantid of the participant
          """
         q = " SELECT participantid FROM participant " \
             " WHERE participant.study       = " + str(study) + \
-            " AND participant.id = '" + participant + "';"  # error? should be turned into a string?
+            " AND participant.id = '" + str(participant) + "';"
         res = self.return_query_result(q)
         found = len(res) == 1
         if found:
